@@ -98,6 +98,10 @@ pub enum DecodeSubcommands {
         #[structopt(short, long)]
         account: Option<String>,
 
+        /// Use this to write the full metadata struct to the output
+        #[structopt(long)]
+        full: bool,
+
         /// Path to JSON file containing a list of mint accounts to decode
         #[structopt(short, long)]
         list_file: Option<String>,
@@ -230,6 +234,26 @@ pub enum SetSubcommands {
         #[structopt(short = "u", long)]
         new_update_authority: String,
     },
+    /// Set is-mutable to false, preventing any future updates to the NFT
+    #[structopt(name = "immutable")]
+    Immutable {
+        /// Path to the creator's keypair file
+        #[structopt(short, long)]
+        keypair: String,
+
+        /// Mint account of corresponding metadata to update
+        #[structopt(short, long)]
+        account: String,
+    },
+    ImmutableAll {
+        /// Path to the creator's keypair file
+        #[structopt(short, long)]
+        keypair: String,
+
+        /// Path to JSON mint accounts file
+        #[structopt(short, long)]
+        mint_accounts_file: String,
+    },
 }
 
 #[derive(Debug, StructOpt)]
