@@ -21,9 +21,10 @@ pub fn process_decode(client: &RpcClient, commands: DecodeSubcommands) -> Result
     match commands {
         DecodeSubcommands::Mint {
             account,
+            full,
             list_file,
             ref output,
-        } => decode_metadata(client, account.as_ref(), list_file.as_ref(), output)?,
+        } => decode_metadata(client, account.as_ref(), full, list_file.as_ref(), output)?,
     }
     Ok(())
 }
@@ -94,6 +95,13 @@ pub fn process_set(client: &RpcClient, commands: SetSubcommands) -> Result<()> {
             &mint_accounts_file,
             &new_update_authority,
         ),
+        SetSubcommands::Immutable { keypair, account } => {
+            set_immutable(&client, &keypair, &account)
+        }
+        SetSubcommands::ImmutableAll {
+            keypair,
+            mint_accounts_file,
+        } => set_immutable_all(&client, &keypair, &mint_accounts_file),
     }
 }
 
